@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use List::MoreUtils qw(any);
 use Storable qw(dclone freeze);
-our $VERSION = '0.06';
+our $VERSION = '0.10';
 
 our $RESERVED_FIELD = '_original';
 our $NEW = 'new';
@@ -137,7 +137,7 @@ sub _mk_helpers($) {
                                                                  unless $field;
 
         return unless $tracked_fields->{$field};
-        return 1 unless defined $self->{$RESERVED_FIELD};
+        return defined $self->{$field} unless defined $self->{$RESERVED_FIELD};
 
         exists $self->{$field} &&
                _is_different $self->{$field}, $self->{$RESERVED_FIELD}{$field};
@@ -257,8 +257,8 @@ You can pass a hash-ref or hash-like list to C<<new>> method.
 
 =item C<< my $object = YourClass->new({name1 => "value1", ...}); >>
 
-The instance created by C<<new>> is regarded as `dirty' since it hasn't been
-stored yet.
+The instance created by C<<new>> is regarded as `dirty' if it has some nonempty
+fields. It's because it hasn't been stored yet.
 
 =back
 
